"""Decision node module for final trading decisions."""

from examples.portfolio_analysis.specialists.decision.models import TradingDecision
from examples.portfolio_analysis.specialists.decision.signature import TradingDecisionSignature

__all__ = ["TradingDecision", "TradingDecisionSignature"]
